@@ -1,22 +1,22 @@
 // Even if allows private_in_public, these are errors.
 
-#![allow(private_in_public)]
+#![allow(private_in_public, dead_code)]
 
 pub enum PublicEnum {
-    Variant(PrivateEnum),
+    V(PrivateEnum), //~ ERROR E0446
 }
 
 enum PrivateEnum {
-    Variant(u8),
+    V(u8),
 }
 
 mod foo {
     pub(crate) enum CrateEnum {
-        Variant(PrivateEnum),
+        V(PrivateEnum), //~ ERROR E0446
     }
 
     enum PrivateEnum {
-        Variant(u8),
+        V(u8),
     }
 }
 
