@@ -1,9 +1,9 @@
 use pin_project::pin_project;
 
 #[pin_project(PinnedDrop)] //~ ERROR E0277
-pub struct Struct {
+struct Struct {
     #[pin]
-    field: u8,
+    f: u8,
 }
 
 fn main() {}
